@@ -133,15 +133,14 @@ class NewReleaseWindow(Gtk.Box):
                 self._image = image
                 self.entry.set_text(image)
                 self.new_release_button.set_sensitive(True)
-                parent.con.remove(parent.release_window)
-                parent.release_window = ReleaseWindow(parent, image, self._module, self._os)
-                parent.con.add(parent.release_window)
-                parent.con.show()
-                parent.show()
-                dialog.destroy()
-                break
+            dialog.destroy()
+            break
 
     def on_create_release_clicked(self, button):
+        self._parent.con.remove(self._parent.release_window)
+        self._parent.release_window = ReleaseWindow(self._parent, self._image,
+                                                    self._module, self._os)
+        self._parent.con.add(self._parent.release_window)
         self._parent.release_window.show_all()
         self.hide()
 
@@ -216,7 +215,7 @@ class ReleaseWindow(Gtk.Box):
                 'Sources': self.sources_page.sources_dict}
 
     def on_back_clicked(self, button):
-        self._parent.main_window.show_all()
+        self._parent.new_release_window.show_all()
         self.hide()
 
     def on_export_release_clicked(self, button):
